@@ -2,6 +2,7 @@
 
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE RecordWildCards #-}
+{-# LANGUAGE CPP #-}
 
 module Hledger.UI.AccountsScreen
  (accountsScreen
@@ -18,7 +19,9 @@ import Control.Monad
 import Control.Monad.IO.Class (liftIO)
 import Data.List
 import Data.Maybe
+#if !(MIN_VERSION_base(4,11,0))
 import Data.Monoid
+#endif
 import qualified Data.Text as T
 import Data.Time.Calendar (Day)
 import qualified Data.Vector as V
@@ -30,7 +33,6 @@ import System.FilePath (takeFileName)
 
 import Hledger
 import Hledger.Cli hiding (progname,prognameandversion)
-import Hledger.Cli.Commands.Add (add)
 import Hledger.UI.UIOptions
 import Hledger.UI.UITypes
 import Hledger.UI.UIState
@@ -85,10 +87,10 @@ asInit d reset ui@UIState{
     -- run the report
     (items,_total) = report ropts' q j
       where
-        -- still using the old balanceReport for change reports as it
-        -- does not include every account from before the report period
-        report | balancetype_ ropts == HistoricalBalance = singleBalanceReport
+        report | balancetype_ ropts == HistoricalBalance = balanceReportFromMultiBalanceReport
                | otherwise                               = balanceReport
+                    -- still using the old balanceReport for change reports as it
+                    -- does not include every account from before the report period
 
 
     -- pre-render the list items
