@@ -1,6 +1,7 @@
 -- The error screen, showing a current error condition (such as a parse error after reloading the journal)
 
 {-# LANGUAGE OverloadedStrings, FlexibleContexts, RecordWildCards #-}
+{-# LANGUAGE CPP #-}
 
 module Hledger.UI.ErrorScreen
  (errorScreen
@@ -14,10 +15,14 @@ import Brick
 -- import Brick.Widgets.Border (borderAttr)
 import Control.Monad
 import Control.Monad.IO.Class (liftIO)
+#if !(MIN_VERSION_base(4,11,0))
 import Data.Monoid
+#endif
 import Data.Time.Calendar (Day)
+import Data.Void (Void)
 import Graphics.Vty (Event(..),Key(..))
-import Text.Megaparsec.Compat
+import Text.Megaparsec
+import Text.Megaparsec.Char
 
 import Hledger.Cli hiding (progname,prognameandversion)
 import Hledger.UI.UIOptions
@@ -105,7 +110,7 @@ esHandle _ _ = error "event handler called with wrong screen type, should not ha
 
 -- | Parse the file name, line and column number from a hledger parse error message, if possible.
 -- Temporary, we should keep the original parse error location. XXX
-hledgerparseerrorpositionp :: ParsecT MPErr String t (String, Int, Int)
+hledgerparseerrorpositionp :: ParsecT Void String t (String, Int, Int)
 hledgerparseerrorpositionp = do
   anyChar `manyTill` char '"'
   f <- anyChar `manyTill` (oneOf ['"','\n'])
