@@ -5,7 +5,6 @@ Released under GPL version 3 or later.
 -}
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
 
 module Hledger.UI.Main where
@@ -16,7 +15,7 @@ import Control.Concurrent (threadDelay)
 import Control.Concurrent.Async
 import Control.Monad
 -- import Control.Monad.IO.Class (liftIO)
-#if !MIN_VERSION_vty(0,15,0)
+#if !MIN_VERSION_vty(5,15,0)
 import Data.Default (def)
 #endif
 -- import Data.Monoid              --
@@ -75,14 +74,12 @@ main = do
 withJournalDoUICommand :: UIOpts -> (UIOpts -> Journal -> IO ()) -> IO ()
 withJournalDoUICommand uopts@UIOpts{cliopts_=copts} cmd = do
   journalpath <- journalFilePathFromOpts copts
-  ej <- readJournalFilesWithOpts (inputopts_ copts) journalpath
+  ej <- readJournalFiles (inputopts_ copts) journalpath
   let fn = cmd uopts
          . pivotByOpts copts
          . anonymiseByOpts copts
-         . journalApplyAliases (aliasesFromOpts copts)
        <=< journalApplyValue (reportopts_ copts)
        <=< journalAddForecast copts
-         . generateAutomaticPostings (reportopts_ copts)
   either error' fn ej
 
 runBrickUi :: UIOpts -> Journal -> IO ()
@@ -109,8 +106,8 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} j = do
                     [v | (k,v) <- rawopts_ copts, k=="args", not $ any (`isPrefixOf` v) ["depth","date"]],
             -- always disable boring account name eliding, unlike the CLI, for a more regular tree
             no_elide_=True,
-            -- show items with zero amount by default, unlike the CLI
-            empty_=True,
+            -- flip the default for items with zero amounts, show them by default
+            empty_=not $ empty_ ropts,
             -- show historical balances by default, unlike the CLI
             balancetype_=HistoricalBalance
             }
@@ -142,27 +139,27 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} j = do
           -- Initialising the accounts screen is awkward, requiring
           -- another temporary UIState value..
           ascr' = aScreen $
-                  asInit d True $
-                  UIState{
-                    aopts=uopts'
-                   ,ajournal=j
-                   ,aScreen=asSetSelectedAccount acct accountsScreen
-                   ,aPrevScreens=[]
-                   ,aMode=Normal
-                   }
+                  asInit d True
+                    UIState{
+                      aopts=uopts'
+                    ,ajournal=j
+                    ,aScreen=asSetSelectedAccount acct accountsScreen
+                    ,aPrevScreens=[]
+                    ,aMode=Normal
+                    }
 
     ui =
       (sInit scr) d True $
-        (if change_ uopts' then toggleHistorical else id) $ -- XXX
-        UIState{
-          aopts=uopts'
-         ,ajournal=j
-         ,aScreen=scr
-         ,aPrevScreens=prevscrs
-         ,aMode=Normal
-         }
+        (if change_ uopts' then toggleHistorical else id) -- XXX
+          UIState{
+            aopts=uopts'
+          ,ajournal=j
+          ,aScreen=scr
+          ,aPrevScreens=prevscrs
+          ,aMode=Normal
+          }
 
-    brickapp :: App (UIState) AppEvent Name
+    brickapp :: App UIState AppEvent Name
     brickapp = App {
         appStartEvent   = return
       , appAttrMap      = const theme
@@ -194,7 +191,7 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} j = do
 
     withAsync
       (getCurrentDay >>= watchDate)
-      $ \_ -> do
+      $ \_ ->
 
       -- start one or more background threads reporting changes in the directories of our files
       -- XXX many quick successive saves causes the problems listed in BUGS
@@ -205,7 +202,7 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} j = do
       -- but gets tied up for ages
       withManager $ \mgr -> do
         dbg1IO "fsnotify using polling ?" $ isPollingManager mgr
-        files <- mapM canonicalizePath $ map fst $ jfiles j
+        files <- mapM (canonicalizePath . fst) $ jfiles j
         let directories = nub $ sort $ map takeDirectory files
         dbg1IO "files" files
         dbg1IO "directories to watch" directories
@@ -215,7 +212,12 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} j = do
           d
           -- predicate: ignore changes not involving our files
           (\fev -> case fev of
-            Modified f _ -> f `elem` files
+#if MIN_VERSION_fsnotify(0,3,0)
+            Modified f _ False
+#else
+            Modified f _
+#endif
+                               -> f `elem` files
             -- Added    f _ -> f `elem` files
             -- Removed  f _ -> f `elem` files
             -- we don't handle adding/removing journal files right now
@@ -226,18 +228,14 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} j = do
           -- action: send event to app
           (\fev -> do
             -- return $ dbglog "fsnotify" $ showFSNEvent fev -- not working
-            dbg1IO "fsnotify" $ showFSNEvent fev
+            dbg1IO "fsnotify" $ show fev
             writeChan eventChan FileChange
             )
 
         -- and start the app. Must be inside the withManager block
-#if MIN_VERSION_vty(0,15,0)
+#if MIN_VERSION_vty(5,15,0)
         let myVty = mkVty mempty
 #else
         let myVty = mkVty def
 #endif
         void $ customMain myVty (Just eventChan) brickapp ui
-
-showFSNEvent (Added    f _) = "Added "    ++ show f
-showFSNEvent (Modified f _) = "Modified " ++ show f
-showFSNEvent (Removed  f _) = "Removed "  ++ show f
